<?php

/*
  This code is part of FusionDirectory (http://www.fusiondirectory.org/)
  Copyright (C) 2003-2010  Cajus Pollmeier
  Copyright (C) 2011-2013  FusionDirectory

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
*/

class roleGeneric extends simplePlugin {

  var $mainTab = TRUE;

  var $objectclasses = array("organizationalRole");

  static function plInfo()
  {
    return array(
      "plShortName"   => _("Role"),
      "plDescription" => _("Role generic"),
      "plSelfModify"  => FALSE,
      "plPriority"    => 1,
      "plCategory"    => array("roles" => array("description"  => _("Roles"), "objectClass"  => "organizationalRole")),
      "plObjectType"  => array("role" => array("name"  => _("Role"), "filter"  => "objectClass=organizationalRole")),

      "plProvidedAcls"  => parent::generatePlProvidedAcls(self::getAttributesInfo())
    );
  }

  /*!
   * \brief Constructor
   *        It will build the select groups choices
   */
  function __construct(&$config, $dn = NULL, $object = NULL)
  {
    parent::__construct($config, $dn, $object);
    $this->attributesInfo['section1']['attrs']['cn']->setUnique(TRUE);
  }

   /*!
   *  \brief The main function : information about attributes
   */
  static function getAttributesInfo ()
  {
    return array(
    // Attributes are grouped by section
    'section1' => array(
        'name'  => _('Generic'),
        'attrs' => array(
          new StringAttribute (_('Name'), _('Name of the role'), 'cn', TRUE),
          new StringAttribute (_('Description'), _('Description of the role'), 'description'),
          new BaseSelectorAttribute (get_ou("roleRDN")),
          new StringAttribute (_('Phone number'), _('Phone number'), 'telephoneNumber'),
          new StringAttribute (_('Fax number'), _('Fax number'), 'facsimileTelephoneNumber'),
          new UsersAttribute(_('Users'), _('Add users for the role'), 'roleOccupant', FALSE)
        )
      )
    );
  }
}
?>
